# textrepo-client

[![GitHub Actions](https://github.com/knaw-huc/textrepo-client-python/workflows/tests/badge.svg)](https://github.com/knaw-huc/textrepo-client-python/actions)
[![Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.](https://www.repostatus.org/badges/latest/wip.svg)](https://www.repostatus.org/#wip)

A Python client for accessing a [textrepo](https://github.com/knaw-huc/textrepo) server

# installing

### using poetry

```commandline
poetry add annorepo-client
```

### using pip

```commandline
pip install annorepo-client
```

### locally, after checking out this repo first

```commandline
pip install .
```

----

[USAGE](usage.md) |
[CONTRIBUTING](CONTRIBUTING.md)